actigraph.sleepr: actigraph.sleepr

actigraph.sleeprR Documentation

actigraph.sleepr

Description

This package implements three standard algorithms for sleep detection from ActiGraph data: Sadeh, Cole-Kripke and Tudor-Locke.

Details

In addition to the help pages, see the README for examples.

Author(s)

Maintainer: Desislava Petkova desislavka@gmail.com

Authors:

Other contributors:

  • John Muschelli [contributor]

See Also

Useful links:


actigraph.sleepr documentation built on Sept. 12, 2026, 5:08 p.m.