tbl_agd: A 'tibble' of activity data exported by an ActiGraph device

View source: R/tbl_agd.R

tbl_agdR Documentation

A tibble of activity data exported by an ActiGraph device

Description

This tibble has several attributes, most importantly, epochlength.

Usage

tbl_agd(data, settings)

Arguments

data

A tibble of raw activity counts.

settings

A tibble of device settings.

Value

A tibble of activity data. It has a time index, timestamp, one or more activity value columns, and attributes holding settings such as epochlength.

Examples

data("gtxplus1day")
gtxplus1day
attr(gtxplus1day, "epochlength")

actigraph.sleepr documentation built on Sept. 12, 2026, 5:08 p.m.