| actigraph.sleepr | R Documentation |
This package implements three standard algorithms for sleep detection from ActiGraph data: Sadeh, Cole-Kripke and Tudor-Locke.
In addition to the help pages, see the README for examples.
Maintainer: Desislava Petkova desislavka@gmail.com
Authors:
Desislava Petkova desislavka@gmail.com
Other contributors:
John Muschelli [contributor]
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.